myutils

package
v0.1.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 8, 2021 License: MIT Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ByteCountDecimal

func ByteCountDecimal(b int64) string

ByteCountDecimal generates human readable file sizes and returns a string

func CheckSpecialPath added in v0.0.6

func CheckSpecialPath(check string) bool

CheckSpecialPath will check a slice of special paths against a folder on disk and return true if it matches

func GetInterfaceIpv4Addr added in v0.1.2

func GetInterfaceIpv4Addr(interfaceName string) (addr string, err error)

GetInterfaceIpv4Addr will return the ip address by name

func MimeByExtension added in v0.0.5

func MimeByExtension(n string) string

MimeByExtension returns the mimetype string depending on the filename and its extension

func RandomNumber added in v0.0.6

func RandomNumber() (big.Int, error)

RandomNumber returns a random int64

func ReturnExt added in v0.0.5

func ReturnExt(n string) string

ReturnExt returns the extension without from a filename

Types

This section is empty.

Jump to